==> haskell-network-ip-0.3.0.3-367-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-DMCPkbOVV9CL3vaD86mZb8
key:                  network-ip-0.3.0.3-DMCPkbOVV9CL3vaD86mZb8
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  1389d2eb007b70f8bbbc218ddfe87522
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-DMCPkbOVV9CL3vaD86mZb8
depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    data-dword-0.3.2.1-ENHPnvsqK9C3hCZyJvLHU6
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    data-serializer-0.3.5-IjJhprdOJb7HaBpQUL3plM
    data-textual-0.3.0.3-J9LSXWnkQeK6GnYTLD9POG
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig
    parsers-0.12.12-CQK003mX4FkGQ5UqIRNCF8
    text-printer-0.5.0.2-Hx4MOTdblWP52A8W9txz92
    type-hint-0.1-BLZkEIaqz7B91MRxOq10xP

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.3-368-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-Ac0M1P30sQVHueGCEQtJQm
key:                  network-ip-0.3.0.3-Ac0M1P30sQVHueGCEQtJQm
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  39db88a6094db35dda99ba55b1f4c2bc
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-Ac0M1P30sQVHueGCEQtJQm
depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    data-dword-0.3.2.1-ENHPnvsqK9C3hCZyJvLHU6
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    data-serializer-0.3.5-4aSoPzgWPv9LkmW0lu1CTk
    data-textual-0.3.0.3-JmsBwccZlFfEas1vxPhJUO
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig
    parsers-0.12.12-DSXrb12WW9pAlDntPLXdEB
    text-printer-0.5.0.2-Hx4MOTdblWP52A8W9txz92
    type-hint-0.1-BLZkEIaqz7B91MRxOq10xP

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
